CodeCommitState

Struct CodeCommitState 

pub struct CodeCommitState {
Show 13 fields pub repositories: BTreeMap<String, Repo>, pub repository_order: Vec<String>, pub templates: BTreeMap<String, Value>, pub template_order: Vec<String>, pub pull_requests: BTreeMap<String, Value>, pub pull_request_order: Vec<String>, pub pull_request_counter: u64, pub pull_request_events: BTreeMap<String, Vec<Value>>, pub pull_request_approvals: BTreeMap<String, BTreeMap<String, BTreeMap<String, String>>>, pub pull_request_overrides: BTreeMap<String, BTreeMap<String, String>>, pub comments: BTreeMap<String, Value>, pub comment_order: Vec<String>, pub tags: BTreeMap<String, BTreeMap<String, String>>,
}
The account-scoped CodeCommit state for one AWS account.

Fields

repositories: BTreeMap<String, Repo>

Repositories keyed by repository name.

repository_order: Vec<String>

Insertion order of repository names (most-recent last).

templates: BTreeMap<String, Value>

Approval-rule templates keyed by template name; value is an ApprovalRuleTemplate-shaped JSON.

template_order: Vec<String>

Insertion order of template names.

pull_requests: BTreeMap<String, Value>

Pull requests keyed by pull-request id; value is a PullRequest-shaped JSON carrying its targets, status, revision id, and approval rules.

pull_request_order: Vec<String>

Insertion order of pull-request ids.

pull_request_counter: u64

Monotonic counter for minting pull-request ids.

pull_request_events: BTreeMap<String, Vec<Value>>

Pull-request event log keyed by pull-request id.

pull_request_approvals: BTreeMap<String, BTreeMap<String, BTreeMap<String, String>>>

Per-pull-request approval state, keyed by pull-request id then revision id then user ARN; value is APPROVE or REVOKE.

pull_request_overrides: BTreeMap<String, BTreeMap<String, String>>

Per-pull-request override state, keyed by pull-request id then revision id; value is the overrider ARN (present means overridden).

comments: BTreeMap<String, Value>

Comments keyed by comment id; value is a Comment-shaped JSON with the thread context (repositoryName, before/after commit, pullRequestId, location) stored alongside under private _ctx* members that are stripped before a comment is returned to the wire.

comment_order: Vec<String>

Insertion order of comment ids.

tags: BTreeMap<String, BTreeMap<String, String>>

Resource tags keyed by resource ARN; value is a key -> value map.